==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/ORGANIZATIONENTERPRISELOCATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ORGANIZATIONENTERPRISELOCATIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ORGANIZATIONENTERPRISELOCATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BODGROUP"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ORGANIZATIONENTERPRISELOCATIONID_Type", propOrder = {
    "organizationid",
    "bodgroup"
})
public class ORGANIZATIONENTERPRISELOCATIONID_Type {

    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "BODGROUP", required = true)
    protected String bodgroup;

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété bodgroup.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBODGROUP() {
        return bodgroup;
    }

    /**
     * Définit la valeur de la propriété bodgroup.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBODGROUP(String value) {
        this.bodgroup = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/ORGANIZATIONENTERPRISELOCATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ORGANIZATIONENTERPRISELOCATIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ORGANIZATIONENTERPRISELOCATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BODGROUP"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ORGANIZATIONENTERPRISELOCATIONID_Type", propOrder = {
    "organizationid",
    "bodgroup"
})
public class ORGANIZATIONENTERPRISELOCATIONID_Type {

    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "BODGROUP", required = true)
    protected String bodgroup;

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the bodgroup property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBODGROUP() {
        return bodgroup;
    }

    /**
     * Sets the value of the bodgroup property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBODGROUP(String value) {
        this.bodgroup = value;
    }

}
